.. webapi-error::
   :title: Disable Extension Failed
   :instance: djblets.webapi.errors.DISABLE_EXTENSION_FAILED

   There was an error disabling the extension. The details of the error
   will be included in the payload.
